==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/network/kotlin/inputs/FirewallPolicyNatRuleCollectionArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.network.kotlin.inputs

import com.pulumi.azurenative.network.inputs.FirewallPolicyNatRuleCollectionArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Any
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Firewall Policy NAT Rule Collection.
 * @property action The action type of a Nat rule collection.
 * @property name The name of the rule collection.
 * @property priority Priority of the Firewall Policy Rule Collection resource.
 * @property ruleCollectionType The type of the rule collection.
 * Expected value is 'FirewallPolicyNatRuleCollection'.
 * @property rules List of rules included in a rule collection.
 */
public data class FirewallPolicyNatRuleCollectionArgs(
    public val action: Output<FirewallPolicyNatRuleCollectionActionArgs>? = null,
    public val name: Output<String>? = null,
    public val priority: Output<Int>? = null,
    public val ruleCollectionType: Output<String>,
    public val rules: Output<List<Any>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.network.inputs.FirewallPolicyNatRuleCollectionArgs> {
    override fun toJava(): com.pulumi.azurenative.network.inputs.FirewallPolicyNatRuleCollectionArgs =
        com.pulumi.azurenative.network.inputs.FirewallPolicyNatRuleCollectionArgs.builder()
            .action(action?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .name(name?.applyValue({ args0 -> args0 }))
            .priority(priority?.applyValue({ args0 -> args0 }))
            .ruleCollectionType(ruleCollectionType.applyValue({ args0 -> args0 }))
            .rules(rules?.applyValue({ args0 -> args0.map({ args0 -> args0 }) })).build()
}

/**
 * Builder for [FirewallPolicyNatRuleCollectionArgs].
 */
@PulumiTagMarker
public class FirewallPolicyNatRuleCollectionArgsBuilder internal constructor() {
    private var action: Output<FirewallPolicyNatRuleCollectionActionArgs>? = null

    private var name: Output<String>? = null

    private var priority: Output<Int>? = null

    private var ruleCollectionType: Output<String>? = null

    private var rules: Output<List<Any>>? = null

    /**
     * @param value The action type of a Nat rule collection.
     */
    @JvmName("btsqanoysfwcfgvo")
    public suspend fun action(`value`: Output<FirewallPolicyNatRuleCollectionActionArgs>) {
        this.action = value
    }

    /**
     * @param value The name of the rule collection.
     */
    @JvmName("pftoxblmcaskapce")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value Priority of the Firewall Policy Rule Collection resource.
     */
    @JvmName("suwdjrudhdnkkpgv")
    public suspend fun priority(`value`: Output<Int>) {
        this.priority = value
    }

    /**
     * @param value The type of the rule collection.
     * Expected value is 'FirewallPolicyNatRuleCollection'.
     */
    @JvmName("wmptxqjeajuwfjmy")
    public suspend fun ruleCollectionType(`value`: Output<String>) {
        this.ruleCollectionType = value
    }

    /**
     * @param value List of rules included in a rule collection.
     */
    @JvmName("cafvcqlkiynjpjyr")
    public suspend fun rules(`value`: Output<List<Any>>) {
        this.rules = value
    }

    @JvmName("sblnauuiwsylkdvq")
    public suspend fun rules(vararg values: Output<Any>) {
        this.rules = Output.all(values.asList())
    }

    /**
     * @param values List of rules included in a rule collection.
     */
    @JvmName("icarhbniiyexkvvd")
    public suspend fun rules(values: List<Output<Any>>) {
        this.rules = Output.all(values)
    }

    /**
     * @param value The action type of a Nat rule collection.
     */
    @JvmName("hcjpxkujfruuvvlg")
    public suspend fun action(`value`: FirewallPolicyNatRuleCollectionActionArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.action = mapped
    }

    /**
     * @param argument The action type of a Nat rule collection.
     */
    @JvmName("xapliedrxyaqyoje")
    public suspend
    fun action(argument: suspend FirewallPolicyNatRuleCollectionActionArgsBuilder.() -> Unit) {
        val toBeMapped = FirewallPolicyNatRuleCollectionActionArgsBuilder().applySuspend {
            argument()
        }.build()
        val mapped = of(toBeMapped)
        this.action = mapped
    }

    /**
     * @param value The name of the rule collection.
     */
    @JvmName("ltybsgurhrwytdol")
    public suspend fun name(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value Priority of the Firewall Policy Rule Collection resource.
     */
    @JvmName("aoimavukqnipwqow")
    public suspend fun priority(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.priority = mapped
    }

    /**
     * @param value The type of the rule collection.
     * Expected value is 'FirewallPolicyNatRuleCollection'.
     */
    @JvmName("womcnnqucabenhot")
    public suspend fun ruleCollectionType(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.ruleCollectionType = mapped
    }

    /**
     * @param value List of rules included in a rule collection.
     */
    @JvmName("nrshgwgnbjdwxntg")
    public suspend fun rules(`value`: List<Any>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.rules = mapped
    }

    /**
     * @param values List of rules included in a rule collection.
     */
    @JvmName("fycwjnlvhxxbaoyh")
    public suspend fun rules(vararg values: Any) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.rules = mapped
    }

    internal fun build(): FirewallPolicyNatRuleCollectionArgs = FirewallPolicyNatRuleCollectionArgs(
        action = action,
        name = name,
        priority = priority,
        ruleCollectionType = ruleCollectionType ?: throw PulumiNullFieldException("ruleCollectionType"),
        rules = rules,
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/network/kotlin/inputs/FirewallPolicyNatRuleCollectionArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.network.kotlin.inputs

import com.pulumi.azurenative.network.inputs.FirewallPolicyNatRuleCollectionArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Any
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Firewall Policy NAT Rule Collection.
 * @property action The action type of a Nat rule collection.
 * @property name The name of the rule collection.
 * @property priority Priority of the Firewall Policy Rule Collection resource.
 * @property ruleCollectionType The type of the rule collection.
 * Expected value is 'FirewallPolicyNatRuleCollection'.
 * @property rules List of rules included in a rule collection.
 */
public data class FirewallPolicyNatRuleCollectionArgs(
    public val action: Output<FirewallPolicyNatRuleCollectionActionArgs>? = null,
    public val name: Output<String>? = null,
    public val priority: Output<Int>? = null,
    public val ruleCollectionType: Output<String>,
    public val rules: Output<List<Any>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.network.inputs.FirewallPolicyNatRuleCollectionArgs> {
    override fun toJava(): com.pulumi.azurenative.network.inputs.FirewallPolicyNatRuleCollectionArgs =
        com.pulumi.azurenative.network.inputs.FirewallPolicyNatRuleCollectionArgs.builder()
            .action(action?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .name(name?.applyValue({ args0 -> args0 }))
            .priority(priority?.applyValue({ args0 -> args0 }))
            .ruleCollectionType(ruleCollectionType.applyValue({ args0 -> args0 }))
            .rules(rules?.applyValue({ args0 -> args0.map({ args0 -> args0 }) })).build()
}

/**
 * Builder for [FirewallPolicyNatRuleCollectionArgs].
 */
@PulumiTagMarker
public class FirewallPolicyNatRuleCollectionArgsBuilder internal constructor() {
    private var action: Output<FirewallPolicyNatRuleCollectionActionArgs>? = null

    private var name: Output<String>? = null

    private var priority: Output<Int>? = null

    private var ruleCollectionType: Output<String>? = null

    private var rules: Output<List<Any>>? = null

    /**
     * @param value The action type of a Nat rule collection.
     */
    @JvmName("qovjthcchywvonjp")
    public suspend fun action(`value`: Output<FirewallPolicyNatRuleCollectionActionArgs>) {
        this.action = value
    }

    /**
     * @param value The name of the rule collection.
     */
    @JvmName("xieuplxarsnlfwpi")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value Priority of the Firewall Policy Rule Collection resource.
     */
    @JvmName("akvoxaqykwowiuxv")
    public suspend fun priority(`value`: Output<Int>) {
        this.priority = value
    }

    /**
     * @param value The type of the rule collection.
     * Expected value is 'FirewallPolicyNatRuleCollection'.
     */
    @JvmName("kecupbyqmchhsruy")
    public suspend fun ruleCollectionType(`value`: Output<String>) {
        this.ruleCollectionType = value
    }

    /**
     * @param value List of rules included in a rule collection.
     */
    @JvmName("jceuqopuhtknltlg")
    public suspend fun rules(`value`: Output<List<Any>>) {
        this.rules = value
    }

    @JvmName("hmvlfakxsisukpvp")
    public suspend fun rules(vararg values: Output<Any>) {
        this.rules = Output.all(values.asList())
    }

    /**
     * @param values List of rules included in a rule collection.
     */
    @JvmName("pmdxlxusftopejiv")
    public suspend fun rules(values: List<Output<Any>>) {
        this.rules = Output.all(values)
    }

    /**
     * @param value The action type of a Nat rule collection.
     */
    @JvmName("esysafkhlmqljwen")
    public suspend fun action(`value`: FirewallPolicyNatRuleCollectionActionArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.action = mapped
    }

    /**
     * @param argument The action type of a Nat rule collection.
     */
    @JvmName("eiounsamsalqbtix")
    public suspend
    fun action(argument: suspend FirewallPolicyNatRuleCollectionActionArgsBuilder.() -> Unit) {
        val toBeMapped = FirewallPolicyNatRuleCollectionActionArgsBuilder().applySuspend {
            argument()
        }.build()
        val mapped = of(toBeMapped)
        this.action = mapped
    }

    /**
     * @param value The name of the rule collection.
     */
    @JvmName("mnwnaeujopgleejb")
    public suspend fun name(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value Priority of the Firewall Policy Rule Collection resource.
     */
    @JvmName("vmaffnmvxdmxtuse")
    public suspend fun priority(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.priority = mapped
    }

    /**
     * @param value The type of the rule collection.
     * Expected value is 'FirewallPolicyNatRuleCollection'.
     */
    @JvmName("qknvtadfohjajnda")
    public suspend fun ruleCollectionType(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.ruleCollectionType = mapped
    }

    /**
     * @param value List of rules included in a rule collection.
     */
    @JvmName("uawaqralcwagnoqe")
    public suspend fun rules(`value`: List<Any>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.rules = mapped
    }

    /**
     * @param values List of rules included in a rule collection.
     */
    @JvmName("reklyiqudvxwixcg")
    public suspend fun rules(vararg values: Any) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.rules = mapped
    }

    internal fun build(): FirewallPolicyNatRuleCollectionArgs = FirewallPolicyNatRuleCollectionArgs(
        action = action,
        name = name,
        priority = priority,
        ruleCollectionType = ruleCollectionType ?: throw PulumiNullFieldException("ruleCollectionType"),
        rules = rules,
    )
}
